from setuptools import setup, find_packages

setup(
    name='isoddeven',
    version='0.3.2',
    description='A Python package to check if a number is odd or even.',
    author='Nilay Sarma',
    packages=find_packages(),
    install_requires=[],
    license="MIT"
)